@@ -1,5 +1,5 @@
 import os, cgi, os.path, deskbar, deskbar.Match, deskbar.Handler
-import gnomevfs, gtk
+import gnomevfs, gtk, gconf
 
 from gettext import gettext as _
 import xml.dom.minidom, urllib
