@@ -41,12 +41,6 @@ class CuemiacEntryUI (DeskbarUI, CuemiacLayoutProvider):
 			self.config_expand = False
 		deskbar.GCONF_CLIENT.notify_add(self.prefs.GCONF_EXPAND, lambda x, y, z, a: self.on_config_expand(z.value))
 		
-		# Set and retreive use selection settings
-		self.use_selection = deskbar.GCONF_CLIENT.get_bool(self.prefs.GCONF_USE_SELECTION)
-		if self.use_selection == None:
-			self.use_selection = True
-		deskbar.GCONF_CLIENT.notify_add(self.prefs.GCONF_USE_SELECTION, lambda x, y, z, a: self.on_use_selection(z.value))
-		
 		# Apply gconf values
 		self.sync_applet_size()
 		
@@ -94,10 +88,6 @@ class CuemiacEntryUI (DeskbarUI, CuemiacLayoutProvider):
 			self.config_expand = value.get_bool()
 			self.sync_applet_size()
 	
-	def on_use_selection(self, value=None):
-		if value != None and value.type == gconf.VALUE_BOOL:
-			self.use_selection = value.get_bool()
-	
 	def sync_applet_size(self):
 		if self.config_expand:
 			self.applet.set_applet_flags(gnomeapplet.EXPAND_MINOR | gnomeapplet.EXPAND_MAJOR)
@@ -130,13 +120,7 @@ class CuemiacEntryUI (DeskbarUI, CuemiacLayoutProvider):
 		except AttributeError:
 			pass
 			
-		if self.use_selection:
-			clipboard = gtk.clipboard_get(selection="PRIMARY")
-			if clipboard.wait_is_text_available():
-				self.cuemiac.get_entry().set_text(clipboard.wait_for_text())
-				
 		self.cuemiac.get_entry().grab_focus()
-		self.cuemiac.get_entry().select_region(0, -1)
 	
 	def get_view (self):
 		return self.cuemiac.get_entry()
